@@ -7,9 +7,9 @@ class graph_object(object):
 #Common layers
 def Get_Gene_Features(self,embedding_dim_genes,gene_features):
     if self.use_v_beta is True:
-        X_v_beta = tf.placeholder(tf.int64, shape=[None, ], name='Input_V_Beta')
+        X_v_beta = tf.compat.v1.placeholder(tf.int64, shape=[None, ], name='Input_V_Beta')
         X_v_beta_OH = tf.one_hot(X_v_beta, depth=len(self.lb_v_beta.classes_))
-        embedding_layer_v_beta = tf.get_variable(name='Embedding_V_beta',
+        embedding_layer_v_beta = tf.compat.v1.get_variable(name='Embedding_V_beta',
                                                  shape=[len(self.lb_v_beta.classes_), embedding_dim_genes])
         X_v_beta_embed = tf.matmul(X_v_beta_OH, embedding_layer_v_beta)
         gene_features.append(X_v_beta_embed)
@@ -19,9 +19,9 @@ def Get_Gene_Features(self,embedding_dim_genes,gene_features):
         embedding_layer_v_beta = None
 
     if self.use_d_beta is True:
-        X_d_beta = tf.placeholder(tf.int64, shape=[None, ], name='Input_D_Beta')
+        X_d_beta = tf.compat.v1.placeholder(tf.int64, shape=[None, ], name='Input_D_Beta')
         X_d_beta_OH = tf.one_hot(X_d_beta, depth=len(self.lb_d_beta.classes_))
-        embedding_layer_d_beta = tf.get_variable(name='Embedding_D_beta',
+        embedding_layer_d_beta = tf.compat.v1.get_variable(name='Embedding_D_beta',
                                                  shape=[len(self.lb_d_beta.classes_), embedding_dim_genes])
         X_d_beta_embed = tf.matmul(X_d_beta_OH, embedding_layer_d_beta)
         gene_features.append(X_d_beta_embed)
@@ -31,9 +31,9 @@ def Get_Gene_Features(self,embedding_dim_genes,gene_features):
         embedding_layer_d_beta = None
 
     if self.use_j_beta is True:
-        X_j_beta = tf.placeholder(tf.int64, shape=[None, ], name='Input_J_Beta')
+        X_j_beta = tf.compat.v1.placeholder(tf.int64, shape=[None, ], name='Input_J_Beta')
         X_j_beta_OH = tf.one_hot(X_j_beta, depth=len(self.lb_j_beta.classes_))
-        embedding_layer_j_beta = tf.get_variable(name='Embedding_J_Beta',
+        embedding_layer_j_beta = tf.compat.v1.get_variable(name='Embedding_J_Beta',
                                                  shape=[len(self.lb_j_beta.classes_), embedding_dim_genes])
         X_j_beta_embed = tf.matmul(X_j_beta_OH, embedding_layer_j_beta)
         gene_features.append(X_j_beta_embed)
@@ -43,9 +43,9 @@ def Get_Gene_Features(self,embedding_dim_genes,gene_features):
         embedding_layer_j_beta = None
 
     if self.use_v_alpha is True:
-        X_v_alpha = tf.placeholder(tf.int64, shape=[None, ], name='Input_V_Alpha')
+        X_v_alpha = tf.compat.v1.placeholder(tf.int64, shape=[None, ], name='Input_V_Alpha')
         X_v_alpha_OH = tf.one_hot(X_v_alpha, depth=len(self.lb_v_alpha.classes_))
-        embedding_layer_v_alpha = tf.get_variable(name='Embedding_V_Alpha',
+        embedding_layer_v_alpha = tf.compat.v1.get_variable(name='Embedding_V_Alpha',
                                                  shape=[len(self.lb_v_alpha.classes_), embedding_dim_genes])
         X_v_alpha_embed = tf.matmul(X_v_alpha_OH, embedding_layer_v_alpha)
         gene_features.append(X_v_alpha_embed)
@@ -55,9 +55,9 @@ def Get_Gene_Features(self,embedding_dim_genes,gene_features):
         embedding_layer_v_alpha = None
 
     if self.use_j_alpha is True:
-        X_j_alpha = tf.placeholder(tf.int64, shape=[None, ], name='Input_J_Alpha')
+        X_j_alpha = tf.compat.v1.placeholder(tf.int64, shape=[None, ], name='Input_J_Alpha')
         X_j_alpha_OH = tf.one_hot(X_j_alpha, depth=len(self.lb_j_alpha.classes_))
-        embedding_layer_j_alpha = tf.get_variable(name='Embedding_J_Alpha',
+        embedding_layer_j_alpha = tf.compat.v1.get_variable(name='Embedding_J_Alpha',
                                                  shape=[len(self.lb_j_alpha.classes_), embedding_dim_genes])
         X_j_alpha_embed = tf.matmul(X_j_alpha_OH, embedding_layer_j_alpha)
         gene_features.append(X_j_alpha_embed)
@@ -77,15 +77,15 @@ def Get_Gene_Features(self,embedding_dim_genes,gene_features):
             gene_features
 
 def Get_HLA_Features(self,GO,embedding_dim):
-    GO.X_hla = tf.placeholder(tf.float32, shape=[None, self.hla_data_seq_num.shape[1]], name='HLA')
-    GO.embedding_layer_hla = tf.get_variable(name='Embedding_HLA',
+    GO.X_hla = tf.compat.v1.placeholder(tf.float32, shape=[None, self.hla_data_seq_num.shape[1]], name='HLA')
+    GO.embedding_layer_hla = tf.compat.v1.get_variable(name='Embedding_HLA',
                                           shape=[len(self.lb_hla.classes_), embedding_dim])
     GO.HLA_Features = tf.matmul(GO.X_hla,GO.embedding_layer_hla)
     return GO.HLA_Features
 
 def Convolutional_Features(inputs,reuse=False,prob=0.0,name='Convolutional_Features',kernel=3,net='ae',
-                           size_of_net = 'medium'):
-    with tf.variable_scope(name,reuse=reuse):
+                           size_of_net = 'medium',l2_reg=0.0):
+    with tf.compat.v1.variable_scope(name,reuse=reuse):
         if size_of_net == 'small':
             units = [12,32,64]
         elif size_of_net == 'medium':
@@ -95,25 +95,26 @@ def Convolutional_Features(inputs,reuse=False,prob=0.0,name='Convolutional_Featu
         else:
             units = size_of_net
 
-        conv = tf.layers.conv2d(inputs, units[0], (1, kernel), 1, padding='same')
-        conv_out = tf.layers.flatten(tf.reduce_max(conv,2))
-        indices = tf.squeeze(tf.cast(tf.argmax(conv, axis=2), tf.float32),1)
-        conv = tf.nn.leaky_relu(conv)
-        conv = tf.layers.dropout(conv,prob)
+        for ii,_ in enumerate(units,0):
+            if ii == 0:
+                conv = tf.compat.v1.layers.conv2d(inputs, units[ii], (1, kernel), 1, padding='same',
+                                                  kernel_regularizer=tf.keras.regularizers.l2(l2_reg))
+                conv_out = tf.compat.v1.layers.flatten(tf.reduce_max(input_tensor=conv, axis=2))
+                indices = tf.squeeze(tf.cast(tf.argmax(input=conv, axis=2), tf.float32), 1)
+                conv = tf.nn.leaky_relu(conv)
+                conv = tf.compat.v1.layers.dropout(conv, prob)
+            else:
+                kernel = 3
+                conv = tf.compat.v1.layers.conv2d(conv, units[ii], (1, kernel), (1, kernel), padding='same',
+                                                  kernel_regularizer=tf.keras.regularizers.l2(l2_reg))
+                conv = tf.nn.leaky_relu(conv)
+                conv = tf.compat.v1.layers.dropout(conv, prob)
 
-        kernel = 3
-        conv_2 = tf.layers.conv2d(conv, units[1], (1, kernel), (1, kernel), padding='same')
-        conv_2 = tf.nn.leaky_relu(conv_2)
-        conv_2 = tf.layers.dropout(conv_2, prob)
-        conv_2_out = tf.layers.flatten(tf.reduce_max(conv_2,2))
-
-        conv_3 = tf.layers.conv2d(conv_2, units[2], (1, kernel), (1, kernel), padding='same')
-        conv_3 = tf.nn.leaky_relu(conv_3)
-        conv_3 = tf.layers.dropout(conv_3, prob)
-        conv_3_out = tf.layers.flatten(tf.reduce_max(conv_3,axis=2))
+        conv_3 = conv
+        conv_3_out = tf.compat.v1.layers.flatten(tf.reduce_max(input_tensor=conv_3,axis=2))
 
         if net == 'ae':
-            return tf.layers.flatten(conv_3),conv_out,indices
+            return tf.compat.v1.layers.flatten(conv_3),conv_out,indices
         else:
             return conv_3_out,conv_out,indices
 
@@ -121,24 +122,24 @@ def Conv_Model(GO, self, trainable_embedding, kernel, use_only_seq,
                use_only_gene,use_only_hla,num_fc_layers=0, units_fc=12):
 
     if self.use_alpha is True:
-        GO.X_Seq_alpha = tf.placeholder(tf.int64,
+        GO.X_Seq_alpha = tf.compat.v1.placeholder(tf.int64,
                                         shape=[None, self.X_Seq_alpha.shape[1], self.X_Seq_alpha.shape[2]],
                                         name='Input_Alpha')
         GO.X_Seq_alpha_OH = tf.one_hot(GO.X_Seq_alpha, depth=21)
 
     if self.use_beta is True:
-        GO.X_Seq_beta = tf.placeholder(tf.int64,
+        GO.X_Seq_beta = tf.compat.v1.placeholder(tf.int64,
                                        shape=[None, self.X_Seq_beta.shape[1], self.X_Seq_beta.shape[2]],
                                        name='Input_Beta')
         GO.X_Seq_beta_OH = tf.one_hot(GO.X_Seq_beta, depth=21)
 
-    GO.prob = tf.placeholder_with_default(0.0, shape=(), name='prob')
-    GO.prob_multisample = tf.placeholder_with_default(0.0, shape=(), name='prob_multisample')
-    GO.sp = tf.sparse.placeholder(dtype=tf.float32, shape=[None, None],name='sp')
-    GO.X_Freq = tf.placeholder(tf.float32, shape=[None, ], name='Freq')
-    GO.X_Counts = tf.placeholder(tf.float32, shape=[None, ], name='Counts')
-    GO.i = tf.placeholder(dtype=tf.int32,shape= [None, ])
-    GO.j = tf.placeholder(dtype=tf.int32,shape = [None, ])
+    GO.prob = tf.compat.v1.placeholder_with_default(0.0, shape=(), name='prob')
+    GO.prob_multisample = tf.compat.v1.placeholder_with_default(0.0, shape=(), name='prob_multisample')
+    GO.sp = tf.compat.v1.sparse.placeholder(dtype=tf.float32, shape=[None, None],name='sp')
+    GO.X_Freq = tf.compat.v1.placeholder(tf.float32, shape=[None, ], name='Freq')
+    GO.X_Counts = tf.compat.v1.placeholder(tf.float32, shape=[None, ], name='Counts')
+    GO.i = tf.compat.v1.placeholder(dtype=tf.int32,shape= [None, ])
+    GO.j = tf.compat.v1.placeholder(dtype=tf.int32,shape = [None, ])
 
     gene_features = []
     GO.X_v_beta, GO.X_v_beta_OH, GO.embedding_layer_v_beta, \
@@ -150,8 +151,8 @@ def Conv_Model(GO, self, trainable_embedding, kernel, use_only_seq,
 
     if trainable_embedding is True:
         # AA Embedding
-        with tf.variable_scope('AA_Embedding'):
-            GO.embedding_layer_seq = tf.get_variable(name='Embedding_Layer_Seq', shape=[21, GO.embedding_dim_aa])
+        with tf.compat.v1.variable_scope('AA_Embedding'):
+            GO.embedding_layer_seq = tf.compat.v1.get_variable(name='Embedding_Layer_Seq', shape=[21, GO.embedding_dim_aa])
             GO.embedding_layer_seq = tf.expand_dims(tf.expand_dims(GO.embedding_layer_seq, axis=0), axis=0)
             if self.use_alpha is True:
                 inputs_seq_embed_alpha = tf.squeeze(
@@ -172,13 +173,15 @@ def Conv_Model(GO, self, trainable_embedding, kernel, use_only_seq,
         GO.Seq_Features_alpha, GO.alpha_out, GO.indices_alpha = Convolutional_Features(inputs_seq_embed_alpha,
                                                                                        kernel=kernel,
                                                                                        name='alpha_conv', prob=GO.prob,
-                                                                                       net=GO.net,size_of_net=GO.size_of_net)
+                                                                                       net=GO.net,size_of_net=GO.size_of_net,
+                                                                                       l2_reg=GO.l2_reg)
 
     if self.use_beta is True:
         GO.Seq_Features_beta, GO.beta_out, GO.indices_beta = Convolutional_Features(inputs_seq_embed_beta,
                                                                                     kernel=kernel,
                                                                                     name='beta_conv', prob=GO.prob,
-                                                                                    net=GO.net,size_of_net=GO.size_of_net)
+                                                                                    net=GO.net,size_of_net=GO.size_of_net,
+                                                                                    l2_reg = GO.l2_reg)
 
     Seq_Features = []
     if self.use_alpha is True:
@@ -226,8 +229,9 @@ def Conv_Model(GO, self, trainable_embedding, kernel, use_only_seq,
     fc = Features
     if num_fc_layers != 0:
         for lyr in range(num_fc_layers):
-            fc = tf.layers.dropout(fc, GO.prob)
-            fc = tf.layers.dense(fc, units_fc, tf.nn.relu)
+            fc = tf.compat.v1.layers.dropout(fc, GO.prob)
+            fc = tf.compat.v1.layers.dense(fc, units_fc, tf.nn.relu,
+                                           kernel_regularizer=tf.keras.regularizers.l2(GO.l2_reg))
 
     return fc
 
@@ -238,9 +242,9 @@ def determine_kr_str(upsample2_beta,GO,self):
     to ensure the output is greater than the input length"""
     for kr in list(range(4,100)):
         for str in list(range(2,100)):
-            upsample3_beta = tf.layers.conv2d_transpose(upsample2_beta, GO.embedding_dim_aa, (1, kr), (1, str),
+            upsample3_beta = tf.compat.v1.layers.conv2d_transpose(upsample2_beta, GO.embedding_dim_aa, (1, kr), (1, str),
                                                         activation=tf.nn.relu)
-            if upsample3_beta.shape[2].value >= self.max_length:
+            if upsample3_beta.shape[2] >= self.max_length:
                 break
         else:
             continue
@@ -251,52 +255,52 @@ def determine_kr_str(upsample2_beta,GO,self):
 def Recon_Loss(inputs,logits):
     #Calculate Per Sample Reconstruction Loss
     shape_layer_1 = inputs.get_shape().as_list()
-    shape_layer_2 = tf.shape(inputs)
+    shape_layer_2 = tf.shape(input=inputs)
     recon_loss = tf.nn.sparse_softmax_cross_entropy_with_logits(labels=inputs, logits=logits)
     recon_loss = tf.reshape(recon_loss,shape=[shape_layer_2[0]*shape_layer_2[1],shape_layer_1[2]])
     w=tf.cast(tf.squeeze(tf.greater(inputs,0),1),tf.float32)
-    recon_loss = tf.reduce_mean(w*recon_loss,axis=1)
+    recon_loss = tf.reduce_mean(input_tensor=w*recon_loss,axis=1)
     return recon_loss
 
 def Latent_Loss(z_log_var,z_mean,alpha=1e-3):
     #Calculate Per Sample Variational Loss
-    latent_loss = -alpha *tf.reduce_sum(1 + z_log_var - tf.square(z_mean) - tf.exp(z_log_var), axis=1)
+    latent_loss = -alpha *tf.reduce_sum(input_tensor=1 + z_log_var - tf.square(z_mean) - tf.exp(z_log_var), axis=1)
     return latent_loss
 
 def Get_Gene_Loss(fc,embedding_layer,X_OH):
-    upsample1 = tf.layers.dense(fc, 128, tf.nn.relu)
-    upsample2 = tf.layers.dense(upsample1, 64, tf.nn.relu)
-    upsample3 = tf.layers.dense(upsample2, embedding_layer.shape[1], tf.nn.relu)
-    logits = tf.matmul(upsample3, tf.transpose(embedding_layer))
-    loss = tf.nn.softmax_cross_entropy_with_logits_v2(labels=X_OH, logits=logits)
+    upsample1 = tf.compat.v1.layers.dense(fc, 128, tf.nn.relu)
+    upsample2 = tf.compat.v1.layers.dense(upsample1, 64, tf.nn.relu)
+    upsample3 = tf.compat.v1.layers.dense(upsample2, embedding_layer.shape[1], tf.nn.relu)
+    logits = tf.matmul(upsample3, tf.transpose(a=embedding_layer))
+    loss = tf.nn.softmax_cross_entropy_with_logits(labels=X_OH, logits=logits)
 
-    predicted = tf.argmax(logits,1)
-    actual = tf.argmax(X_OH,1)
-    accuracy = tf.reduce_mean(tf.cast(tf.equal(predicted,actual),tf.float32))
+    predicted = tf.argmax(input=logits,axis=1)
+    actual = tf.argmax(input=X_OH,axis=1)
+    accuracy = tf.reduce_mean(input_tensor=tf.cast(tf.equal(predicted,actual),tf.float32))
 
     return loss,accuracy
 
 def Get_HLA_Loss(fc,embedding_layer,X_OH,alpha=1.0):
-    upsample1 = tf.layers.dense(fc, 128, tf.nn.relu)
-    upsample2 = tf.layers.dense(upsample1, 64, tf.nn.relu)
-    upsample3 = tf.layers.dense(upsample2, embedding_layer.shape[1], tf.nn.relu)
-    logits = tf.matmul(upsample3, tf.transpose(embedding_layer))
-    loss = tf.reduce_mean(tf.nn.sigmoid_cross_entropy_with_logits(labels=X_OH, logits=logits),-1)
+    upsample1 = tf.compat.v1.layers.dense(fc, 128, tf.nn.relu)
+    upsample2 = tf.compat.v1.layers.dense(upsample1, 64, tf.nn.relu)
+    upsample3 = tf.compat.v1.layers.dense(upsample2, embedding_layer.shape[1], tf.nn.relu)
+    logits = tf.matmul(upsample3, tf.transpose(a=embedding_layer))
+    loss = tf.reduce_mean(input_tensor=tf.nn.sigmoid_cross_entropy_with_logits(labels=X_OH, logits=logits),axis=-1)
 
     predicted = tf.greater(logits,0.9)
-    accuracy = tf.reduce_mean(tf.cast(tf.equal(predicted,tf.cast(X_OH,tf.bool)),tf.float32))
+    accuracy = tf.reduce_mean(input_tensor=tf.cast(tf.equal(predicted,tf.cast(X_OH,tf.bool)),tf.float32))
     return loss, accuracy
 
 
 def calc_entropy(a):
-    return -tf.reduce_sum(a * tf.log(a))
+    return -tf.reduce_sum(input_tensor=a * tf.math.log(a))
 
 def calc_norm_entropy(a):
-    return calc_entropy(a) / tf.log(tf.cast(tf.shape(a)[0], tf.float32))
+    return calc_entropy(a) / tf.math.log(tf.cast(tf.shape(input=a)[0], tf.float32))
 
 def sparsity_loss(z_w,sparsity_alpha):
-    eigen = tf.linalg.norm(z_w, axis=0)
-    eigen_prop = eigen / tf.reduce_sum(eigen)
+    eigen = tf.linalg.norm(tensor=z_w, axis=0)
+    eigen_prop = eigen / tf.reduce_sum(input_tensor=eigen)
     sparsity_cost = calc_norm_entropy(eigen_prop)
     sparsity_cost = sparsity_alpha * sparsity_cost
     return sparsity_cost
@@ -341,13 +345,13 @@ def MultiSample_Dropout(X,num_masks=2,activation=tf.nn.relu,use_bias=True,
     """
     out = []
     for i in range(num_masks):
-        fc = tf.layers.dropout(X,rate=rate)
+        fc = tf.compat.v1.layers.dropout(X,rate=rate)
         if i==0:
             reuse=False
         else:
             reuse=True
 
-        with tf.variable_scope(name,reuse=reuse):
-            out.append(tf.layers.dense(fc,units=units,activation=activation,use_bias=use_bias,
-                                       kernel_regularizer=tf.contrib.layers.l1_regularizer(reg)))
-    return tf.reduce_mean(tf.stack(out),0)
+        with tf.compat.v1.variable_scope(name,reuse=reuse):
+            out.append(tf.compat.v1.layers.dense(fc,units=units,activation=activation,use_bias=use_bias,
+                                       kernel_regularizer=tf.keras.regularizers.l1(reg)))
+    return tf.reduce_mean(input_tensor=tf.stack(out),axis=0)
